Crate codex_file_search

Crate codex_file_search 

Structs

Cli
Fuzzy matches filenames under a directory.
FileMatch
A single match result returned from the search.
FileSearchOptions
FileSearchResults
FileSearchSession
FileSearchSnapshot

Enums

MatchType

Traits

Reporter
SessionReporter

Functions

cmp_by_score_desc_then_path_asc
Returns a comparator closure suitable for slice.sort_by(...) that orders items by descending score and then ascending path using the provided accessors.
create_session
file_name_from_path
Returns the final path component for a matched path, falling back to the full path.
run
The worker threads will periodically check cancel_flag to see if they should stop processing files.
run_main