Structs
- Cli
- Fuzzy matches filenames under a directory.
- File
Match - A single match result returned from the search.
- File
Search Options - File
Search Results - File
Search Session - File
Search Snapshot
Enums
Traits
Functions
- cmp_
by_ score_ desc_ then_ path_ asc - Returns a comparator closure suitable for
slice.sort_by(...)that orders items by descending score and then ascending path using the provided accessors. - create_
session - file_
name_ from_ path - Returns the final path component for a matched path, falling back to the full path.
- run
- The worker threads will periodically check
cancel_flagto see if they should stop processing files. - run_
main