pub trait SessionReporter:
Send
+ Sync
+ 'static {
// Required methods
fn on_update(&self, snapshot: &FileSearchSnapshot);
fn on_complete(&self);
}Required Methods
Sourcefn on_update(&self, snapshot: &FileSearchSnapshot)
fn on_update(&self, snapshot: &FileSearchSnapshot)
Called when the debounced top-N changes.
Sourcefn on_complete(&self)
fn on_complete(&self)
Called when the session becomes idle or is cancelled. Guaranteed to be called at least once per update_query.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".